api.sensors.v1.test_helpers.status package — Argus-Toolbelt 1.0 documentation

# api.sensors.v1.test_helpers.status package

## Submodules

## api.sensors.v1.test_helpers.status.find_sensors module

`api.sensors.v1.test_helpers.status.find_sensors.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/search, respond with HTTP 403

`api.sensors.v1.test_helpers.status.find_sensors.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/search, respond with HTTP 404

`api.sensors.v1.test_helpers.status.find_sensors.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/search, respond with HTTP 200

`api.sensors.v1.test_helpers.status.find_sensors.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/search, respond with HTTP 401

## api.sensors.v1.test_helpers.status.get_sensor module

`api.sensors.v1.test_helpers.status.get_sensor.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/w+, respond with HTTP 403

`api.sensors.v1.test_helpers.status.get_sensor.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/w+, respond with HTTP 404

`api.sensors.v1.test_helpers.status.get_sensor.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/w+, respond with HTTP 200

`api.sensors.v1.test_helpers.status.get_sensor.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status/w+, respond with HTTP 401

## api.sensors.v1.test_helpers.status.list_sensors module

`api.sensors.v1.test_helpers.status.list_sensors.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status, respond with HTTP 403

`api.sensors.v1.test_helpers.status.list_sensors.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status, respond with HTTP 404

`api.sensors.v1.test_helpers.status.list_sensors.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status, respond with HTTP 200

`api.sensors.v1.test_helpers.status.list_sensors.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/sensors/v1/status, respond with HTTP 401

## Module contents